import 'bootstrap/dist/css/bootstrap.min.css';

import Container from 'react-bootstrap/Container';
import Nav from 'react-bootstrap/Nav';
import Navbar from 'react-bootstrap/Navbar';
import Cookies from 'js-cookie'; 
import {useNavigate} from "react-router-dom";
import axios from 'axios';
import { ToastContainer, toast } from 'react-toastify';
function NavBar() {
  const navigate = useNavigate();
  
  const userLogout = () => {
    Cookies.remove('token');
    navigate('/');
  }

  async function handleRequest() {
    let user_id;
    let email;
    try {
      const config = {
        headers: {
          Authorization: `Bearer ${Cookies.get('token')}`,
        }
      };
      const response = await axios.get('http://localhost:3000/api/user', config);
      const data = JSON.parse(JSON.stringify(response.data));
      user_id = data.user_id;
      email = data.email;
    } catch (error) {
      console.error('Error getting user informations:', error);
      toast.error('Error getting user information to apply for premium account', {
        position: "bottom-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
        theme:"light",
        className: "toast-message",
      });        
    }
  
    try {
      const response = await axios.post(
        'http://localhost:3000/api/premium/request',
        { userID: user_id, email: email},
        {
          headers: {
            Authorization: `Bearer ${Cookies.get('token')}`,
          },
        }
      );
  
      if (response.data.message === "Request for this user already exists and still waiting for approval") {
        // alert("User has already made a request and is waiting for approval.");
        toast.warn('This user has already made a request and is waiting for approval.', {
          position: "bottom-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
          theme:"light",
          className: "toast-message",
        });  
      } else {
        alert(response.data);
        toast.success(response.data, {
          position: "bottom-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
          theme:"light",
          className: "toast-message",
        });  
      }
    } catch (error) {
      console.error('Error:', error);
      toast.error('Error applying for premium account', {
        position: "bottom-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
        theme:"light",
        className: "toast-message",
      });
    }
  }
  

  return (
      <Navbar expand="lg" fixed="top" style={{borderBottom: '1px solid black', zIndex: 10}} className="bg-white w-[100vw] justify-content-between">
        <ToastContainer
          position="bottom-center"
          autoClose={5000}
          hideProgressBar={false}
          newestOnTop={false}
          closeOnClick
          rtl={false}
          pauseOnFocusLoss
          draggable
          pauseOnHover
          progressStyle={{ backgroundColor: 'blackPallete' }} 
        />
        <Container>
          <Navbar.Brand href="#home">React-Bootstrap</Navbar.Brand>
          <Navbar.Toggle aria-controls="basic-navbar-nav" />
          <Navbar.Collapse id="basic-navbar-nav">
            <Nav className="ms-auto space-x-2">
              <Nav.Link className='bg-yellowPallete p-2'>
                <button className='font-semibold border-double border-yellow border-black-3' onClick={handleRequest}>Apply For Premium</button>
              </Nav.Link>
              <Nav.Link href="/home">Home</Nav.Link>
              <Nav.Link href="/new-blog">Write</Nav.Link>
              <Nav.Link onClick={userLogout}>Logout</Nav.Link>
            </Nav>
          </Navbar.Collapse>
        </Container>
      </Navbar>
  );
}

export default NavBar;