import NavBar from "../components/Navbar";
// import { useNavigate } from "react-router-dom";
import { FaRegComment, FaStar, FaPencilAlt, FaTrash } from "react-icons/fa";
import { useState, useEffect } from 'react';
import axios from "axios";
import {BlogContent} from "../types/blog";
import { useNavigate, useParams } from "react-router-dom";
import checkToken from "../middleware/Auth";
import Cookies from 'js-cookie';
import { UserData } from "../types/user";
import { ToastContainer, toast } from "react-toastify";
import ModalComponent from "../components/Modal";
import { Modal } from "react-bootstrap";

function Blog() {

  const [comment, setComment] = useState('');
  const [blog, setBlog] = useState<BlogContent>();
  const { id } = useParams(); // Menggunakan useParams untuk mengambil 'id' dari URL
  const navigate = useNavigate();
  const [userData, setUserData] = useState<UserData>();

  useEffect(() => {
    const fetchUserData = async () => {
      try {
        const config = {
          headers: {
            Authorization: `Bearer ${Cookies.get('token')}`,
          },
        };
        const response = await axios.get('http://localhost:3000/api/user/', config);
        // Assuming the response.data contains user_id and user_name
        setUserData(response.data);
        console.log("User data", response.data.data);
      } catch (error) {
        console.error('Error fetching user data:', error);
      }
    };

    fetchUserData();
  }, []);  

  function handleCommentChange(e: React.ChangeEvent<HTMLTextAreaElement>) {
    setComment(e.target.value);
  }

  const handleCommentSubmit = async () => {
    if (comment == '') {
      toast.warn('Fill the comment section first', {
        position: "bottom-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
        theme: "light",
      });  
    }
    let user_id;
    let user_name;
    try {
      const config = {
        headers: {
          Authorization: `Bearer ${Cookies.get('token')}`,
        }
      };
      const response = await axios.get('http://localhost:3000/api/user', config);
      const data = JSON.parse(JSON.stringify(response.data));
      user_id = data.user_id;
      user_name = data.user_name;
      
      try {
        await axios.post(`http://localhost:3000/api/comments/${id}`, {
          comment_content: comment,
          user_id: user_id,
          user_name: user_name
        }, {
          headers: {
            Authorization: `Bearer ${Cookies.get('token')}`,
            'Content-Type': 'application/json',
          },
        });

        navigate(`/blog/${id}`)
      } catch (error) {
        console.error('Error publishing comment:', error);
        toast.error('Error publishing comment', {
          position: "bottom-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
          theme: "light",
        });    
      }
      setComment('');  
    } catch (error) {
      console.error('Error publishing comment:', error);
      toast.error('Error publishing comment', {
        position: "bottom-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
        theme: "light",
      });  
    }
  }

  const handleEdit = () => {
    navigate(`/editblog/${id}`);
    setComment('');
  }

  const handleDelete = async () => {
    try {
      const config = {
        headers: {
          Authorization: `Bearer ${Cookies.get('token')}`,
        }
      };
      const response = await axios.delete(`http://localhost:3000/api/blogs/${id}`, config);
      if (response.status === 200) {
        navigate("/home");
      } else {
        console.error("Unexpected response status:", response.status);
        toast.error('Error deleting blog (' + response.status + ')', {
          position: "bottom-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
          theme: "light",
        });    
      }  
    } catch (error) {
      console.error("Error deleting blog", error);
      toast.error('Error deleting blog', {
        position: "bottom-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
        theme: "light",
      });  
    }
  }


  useEffect(() => {
    const isValid = checkToken();

    if (!isValid) {
      navigate('/');
      return;
    }

    const fetchBlog = async () => {
      if (
        userData && 
        blog && 
        userData?.is_premium || !blog?.is_premium || blog?.user_id == userData?.user_id
      ) {      
        try {
          const config = {
            headers: {
              Authorization: `Bearer ${Cookies.get('token')}`,
            }
          };
          const response = await axios.get(`http://localhost:3000/api/blogs/${id}`, config)
          setBlog(response.data.data);
        } catch (error) {
          console.error("Error fetching blog:", error);
        }
      }
    }
  
    fetchBlog();
  }, [blog, id, navigate, userData]);

  const [show, setShow] = useState(true);

  const handleClose = () => {
    setShow(false)
    navigate("/home")
  };

  return (
    <div className="font-helvetica mt-24">
    <ToastContainer
        position="bottom-center"
        autoClose={5000}
        hideProgressBar={false}
        newestOnTop={false}
        closeOnClick
        rtl={false}
        pauseOnFocusLoss
        draggable
        pauseOnHover
        progressStyle={{ backgroundColor: 'blackPallete' }} 
      />

      <NavBar />
      <div>
        {userData?.is_premium || !blog?.is_premium || blog?.user_id == userData?.user_id ? (
          <></>
        ) : (
          <Modal show={show} onHide={handleClose} backdrop="static">
            <Modal.Body>This is a premium content</Modal.Body>
            <Modal.Footer>
              <button 
                onClick={handleClose}
                className="bg-[#6b6b6b] text-[21px] bg-opacity-20 mr-3 px-3 py-1"
              > Close </button>
            </Modal.Footer>
          </Modal>
        )}
      </div>
      <div className="main-cont w-[55vw] mx-auto bg-blue">
        {blog?.is_premium && (
          <div className="w-[100%] flex flex-row items-center mb-4 text-[#6b6b6b]">
            <div className="mr-2">
              <FaStar color="gold" />
            </div>
            Member-only blog
          </div>
        )}

    <h1 className="text-[#242424] mb-2 md:mb-3 text-[32px] sm:text-[42px] font-extrabold">
          {blog?.title}
        </h1>
        <div className="mb-3 sm:mb-4">
          <div className="text-[#242424] text-[12px] sm:text-[16px]">
            {blog?.user_name}
          </div>
          <div className="text-[#6b6b6b] text-[10px] sm:text-[14px]">
            {blog?.date}
          </div>
        </div>

        <div className="flex flex-row mb-5 items-center text-[#6b6b6b]">
          <div className="flex flex-row items-center mr-3">
            <div className="mr-2">
              <FaRegComment />
            </div>
            {blog?.comments.length}
          </div>
          {userData && blog && userData.user_id === blog.user_id && (
            <button className="mr-3" onClick={handleEdit}>
              <FaPencilAlt />
            </button>
          )}
          {userData && blog && userData.user_id === blog.user_id && (
            <ModalComponent 
              showModalComponent={
                <button className="mr-3">
                  <FaTrash />
                </button>
              }
              triggerComponent={
                <button 
                  onClick={handleDelete} 
                  className="bg-[#6b6b6b] text-[21px] bg-opacity-20 mr-3 px-3 py-1"
                > Yes </button>
              }
              body="Are you sure you want to delete this blog?"
              footer="No"
            />
          )}
        </div>

        <div className="w-full md:w-[100%] mb-10">
          <img src={"http://localhost:3000" + blog?.image_path} alt="" className="w-full" />
        </div>
        <div className="font-serif sm:text-[20px] text-[12px] mb-10 text-[#242424]">
          {blog?.content}
        </div>

        <div className="mb-3 sm:text-[32px] text-[22px] text-bold">
          Leave a comment
        </div>
        <div className="mb-10">
          <textarea
            className="w-full resize-none"
            placeholder="Write a comment here"
            value={comment}
            onChange={handleCommentChange}
          />
          <button
            onClick={handleCommentSubmit}
            className="bg-[#6b6b6b] sm:text-[20px] text-[16px] bg-opacity-20 px-3 py-1"
          > Send </button>
        </div>

        <div className="w-full md:w-[100%] my-2">
          {blog?.comments.map((comment, index) => (
            <div className="bg-slate-200 p-3 mb-4" key={index}>
              <div className="flex flex-row w-[100%] justify-between">
                <div className="text-[#6b6b6b] text-[20px]">
                  {comment.user_name}
                </div>
                <div className="text-[#6b6b6b]">
                  {comment.date}
                </div>
              </div>
              <div className="text-[#242424]">
                {comment.comment}
              </div>
            </div>
          ))}
        </div>
      </div>
    </div>  
  )
}

export default Blog;