import NavBar from "../components/Navbar";
import { useNavigate } from "react-router-dom";
import { useState, useEffect } from 'react';
import axios from "axios";
import { useParams } from "react-router-dom";
import Cookies from 'js-cookie';
import checkToken from "../middleware/Auth";
import { toast, ToastContainer } from "react-toastify";
import ModalComponent from "../components/Modal";
import 'bootstrap/dist/css/bootstrap.min.css';


function EditBlog() {
  const navigate = useNavigate();
  const { id } = useParams(); 
  const [content, setContent] = useState('');
  const [title, setTitle] = useState('');
  const [image, setImage] = useState<File | undefined>(undefined);

  useEffect(() => {
    const isValid = checkToken();
    
    if (!isValid) {
      navigate('/');
      return;
    }

    const fetchBlog = async () => {
      try {
        const config = {
          headers: {
            Authorization: `Bearer ${Cookies.get('token')}`,
          }
        };
        const response = await axios.get(`http://localhost:3000/api/blogs/${id}`, config)
        setTitle(response.data.data.title);
        setContent(response.data.data.content);
      } catch (error) {
        toast.error('Error fetching blog', {
          position: "bottom-center",
          autoClose: 5000,
          hideProgressBar: false,
          closeOnClick: true,
          pauseOnHover: true,
          draggable: true,
          progress: undefined,
          theme: "light",
        });  
        console.error("Error fetching blog: ", error);
      }
    };

    fetchBlog();
  }, [id, navigate]);

  function handleContentChange(e: React.ChangeEvent<HTMLTextAreaElement>) {
    setContent(e.target.value);
  }
  
  function handleImageChange(e: React.ChangeEvent<HTMLInputElement>) {
    const file = e.target.files ? e.target.files[0] : undefined;
    setImage(file);
  }

  const handleCancel = () => {
    navigate(`/blog/${id}`)
  }

  const handleSave = async () => {
    const formData = new FormData();
    formData.append('title', title);
    formData.append('content', content);
    if (image) {
      formData.append('file', image);
    }
    
    for (const value of formData.values()) {
      console.log(value);
    }
    
    try {
      await axios.put(`http://localhost:3000/api/blogs/${id}`, formData, {
        headers: {
          Authorization: `Bearer ${Cookies.get('token')}`,
          'Content-Type': 'multipart/form-data',
        },
      });
    
      navigate(`/blog/${id}`);
    } catch (error) {
      console.error('Error publishing blog:', error);
      toast.error('Error publishing blog', {
        position: "bottom-center",
        autoClose: 5000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
        theme:"light",
        className: "toast-message",
      });        

    }
  }

  return (
    <div className="font-serif mt-24">
      <ToastContainer
        position="bottom-center"
        autoClose={5000}
        hideProgressBar={false}
        newestOnTop={false}
        closeOnClick
        rtl={false}
        pauseOnFocusLoss
        draggable
        pauseOnHover
        progressStyle={{ backgroundColor: 'blackPallete' }} 
      />
      <NavBar/>
      <div className="main-cont w-[55vw] mx-auto bg-blue">
        <div className="mb-3 text-[32px] text-bold">
          <input 
            type="text" 
            className="w-[100%] text-[32px] border-0 focus:outline-none"
            placeholder="Title"
            name="title"
            value={title}
            onChange={(e) => setTitle(e.target.value)}
            id="title"
          />
        </div>
        <div className="mb-3 ml-3 border-solid border-1 p-3 border-greyPallete">
          <div className="text-greyPallete mb-3">
            Choose Blog Thumbnail
          </div>
          <label htmlFor="fileInput" className="block cursor-pointer">
            <input
              type="file"
              accept="image/*"
              onChange={handleImageChange}
              id="fileInput"
              className="hidden"
            />
            <div className="bg-white border-solid border-2 border-greyPallete w-full p-2 rounded-md">
              <span className="text-greyPallete block overflow-hidden overflow-ellipsis whitespace-nowrap">
                {image ? image.name : "No file chosen"}
              </span>
            </div>
          </label>
        </div>

        <div className="mb-20">
          <textarea
            className="w-full h-[70vh] text-[21px] border-0 resize-none"
            placeholder="Tell your story..."
            value={content}
            onChange={handleContentChange}
          />
          <div className="flex flex-row space-x-3">
            <ModalComponent 
              showModalComponent={
                <button 
                  className="bg-[#6b6b6b] text-[21px] bg-opacity-20 mr-3 px-3 py-1"
                > Back </button>
              }
              triggerComponent={
                <button 
                  onClick={handleCancel} 
                  className="bg-[#6b6b6b] text-[21px] bg-opacity-20 mr-3 px-3 py-1"
                > Yes </button>
              }
              body="Your changes will not be saved"
              footer="No"
            />
            <ModalComponent 
              showModalComponent={
                <button 
                  className="bg-[#6b6b6b] text-[21px] bg-opacity-20 px-3 py-1"
                > Save </button>}
              triggerComponent={
                <button 
                  onClick={handleSave} 
                  className="bg-[#6b6b6b] text-[21px] bg-opacity-20 px-3 py-1"
                > Save </button>}
              body="Are you sure you want to save this?"
              footer="Cancel"
            />
          </div>
        </div>
      </div>
    </div>
  )
}

export default EditBlog;