import NavBar from "../components/Navbar";
import { useState, useEffect } from 'react';
import { useNavigate, useLocation } from "react-router-dom";
import {BlogContent} from "../types/blog";
import axios from "axios";
import Cookies from 'js-cookie';
import checkToken from "../middleware/Auth";

function Home() {
  const [blogs, setBlogs] = useState<BlogContent[]>();
  const navigate = useNavigate();
  const location = useLocation();

  useEffect(() => {
    const isValid = checkToken();
    
    if (!isValid) {
      navigate('/');
      return;
    }
  
    const fetchBlog = async () => {
      try {
        const config = {
          headers: {
            Authorization: `Bearer ${Cookies.get('token')}`,
          }
        };
        const response = await axios.get(`http://localhost:3000/api/blogs/`, config);
        setBlogs(response.data.data);
      } catch (error) {
        console.error("Error fetching blog:", error);
      }
    };
  
    fetchBlog();
  }, [navigate]);
  

  const handleRedir = (e: React.MouseEvent<HTMLDivElement>) => {
    const blogId = e.currentTarget.getAttribute('id'); // Mengambil ID blog dari elemen yang ditekan
    if (blogId) {
      navigate(`/blog/${blogId}`);
    }
  }

  setTimeout(() => {
      location.state.loginSuccess = false
  }, 3000);


  return (
    <div className=" font-helvatica">
      <NavBar/>
      <div className="main-cont">
        <div>
          <div className="sm:pl-16 pl-12 min-h-screen mx-auto text-[#242424] font-serif border-b-[1px] border-black flex flex-col justify-center bg-[#FFD700]">
            <h1 className="text-[18vw] sm:text-[100px]">
              Stay curious.
            </h1>
            <h2 className="text-[4vw] sm:text-[25px] text-[#242424]">
              Discover stories, thinking, and expertise from writers on any topic.
            </h2>
          </div>
          <div className="blog-list-cont mx-auto my-5 w-[95%]">
            {blogs?.map((blog, index) => (
              <div key={index}>
                <div className="blog-list flex flex-col mb-3 justify-center items-center w-[100%] mx-auto">
                  <div onClick={handleRedir} id={blog.blog_id.toString()} className="blog-item flex flex-row w-[80%] justify-between items-center">
                    <div className="mr-3">
                      <div className="sm:text-[13px] text-[11px] text-[#242424] sm:pb-[8px] pb-[5px] font-medium">
                        {blog.user_name}
                      </div>
                      <div className="sm:text-[20px] text-[16px] whitespace-nowrap overflow-hidden overflow-ellipsis sm:w-[540px] w-[200px] text-[#242424] font-extrabold">
                        {blog.title}
                      </div>
                      <div className="sm:text-[16px] text-[13px] sm:w-[400px] w-[200px] h-[60px] text-[#6b6b6b] overflow-ellipsis font-light overflow-hidden">
                        <div className="line-clamp-2"> 
                          {blog.content}
                        </div>
                      </div>

                      {blog.is_premium ? 
                        <div className="flex flex-row sm:mt-[8px] mt-[5px] sm:text-[13px] text-[11px] text-[#6b6b6b]">
                          <div>
                            {blog.date}
                          </div>
                          <span className="mx-2 font-bold">
                            .
                          </span>
                          <div className="sm:px-3 px-2 bg-[#FFD700] text-[#242424] font-bold rounded-full">
                            Premium
                          </div>
                        </div>
                        : 
                        <div className="flex flex-row sm:mt-[8px] mt-[5px] sm:text-[13px] text-[11px] text-[#6b6b6b]">
                          <div>
                            {blog.date}
                          </div>
                        </div>
                      }
                    </div>
                    <div>
                      <img src={"http://localhost:3000" + blog.image_path} alt="blog thumbnail" className="sm:w-[100px] w-[70px] sm:max-w-[100px] max-w-[70px] sm:max-h-[100px] max-h-[70px] object-contain" />
                    </div>
                  </div>

                </div>
              </div>        
            ))}
          </div>
        </div>

      </div>
    </div>
  )
}

export default Home;