import { useState} from 'react';
import { useNavigate, Link} from "react-router-dom";
import axios from 'axios';
import Cookies from 'js-cookie';

const Login = (): JSX.Element => {
    const navigate = useNavigate();
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const [loginError, setLoginError] = useState('');

    const userLogin = async () => {
        if (!email || !password) {
            setLoginError('Please provide both email and password.');
            return;
        }

        try {
            const response = await axios.post('http://localhost:3000/api/login', {
                email,
                password
            }, {
                headers: {
                    'Content-Type': 'application/json'
                }
            });
        
            if (response.status === 200) {
                const data = JSON.parse(JSON.stringify(response.data));
                navigate('/Home');
                setEmail('');
                setPassword('');
                Cookies.set('token', data.token);
            } else {
                alert(`Login error: ${response.data.msg}`);
            }
        } catch (error) {
            alert(`Error fetching: ${error}`);
        }
    }


    return (
    <div className="font-helvatica bg-yellowPallete h-screen flex justify-center items-center">
        <div className="bg-white p-10 rounded-lg shadow-lg">
            <h1 className="text-[24px] font-bold text-blackPallete">Login</h1>
            <form className='text-[16px]'>
            <div className="mb-4">
                <label className="text-gray block mb-2" htmlFor="email">
                    Email
                </label>
                <input
                    type="email"
                    id="email"
                    value={email}
                    onChange={(e) => setEmail(e.target.value)}
                    className="w-full p-2 border rounded"
                />
            </div>
            <div className="mb-2">
                <label className="text-blackPallete block mb-2" htmlFor="password">
                    Password
                </label>
                <input
                    type="password"
                    id="password"
                    value={password}
                    onChange={(e) => setPassword(e.target.value)}
                    className="w-full p-2 border rounded"
                />
            </div>
            {loginError && (
                    <div className="text-red300 text-sm">{loginError}</div>
            )}
            <div className='mb-2'>
                <p className='text-greyPallete'>Don't have an account? <Link to="/register" className="text-greyPallete font- hover:underline hover:text-yellowPallete">Sign up here</Link></p>
            </div>
            <button
                type="button"
                onClick={userLogin}
                className="bg-greyPallete text-white py-2 px-4 rounded hover:bg-opacity-80"
            >
                Login
            </button>
            </form>
        </div>
    </div>
    )
  }
  
  export default Login
  